/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * The result of a voter info lookup query.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VoterInfoResponse extends GenericJson {

  /**
   * Contests that will appear on the voter's ballot
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Contest> contests;

  static {
    // hack to force ProGuard to consider Contest used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Contest.class);
  }

  /**
   * Locations where the voter is eligible to vote early, prior to election day
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<PollingLocation> earlyVoteSites;

  static {
    // hack to force ProGuard to consider PollingLocation used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(PollingLocation.class);
  }

  /**
   * The election that was queried.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Election election;

  /**
   * The kind, fixed to "civicinfo#voterInfoResponse".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The normalized version of the requested address
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SimpleAddressType normalizedInput;

  /**
   * Locations where the voter is eligible to vote on election day. For states with mail-in voting
   * only, these locations will be nearby drop box locations. Drop box locations are free to the
   * voter and may be used instead of placing the ballot in the mail.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<PollingLocation> pollingLocations;

  static {
    // hack to force ProGuard to consider PollingLocation used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(PollingLocation.class);
  }

  /**
   * Local Election Information for the state that the voter votes in. For the US, there will only
   * be one element in this array.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<AdministrationRegion> state;

  static {
    // hack to force ProGuard to consider AdministrationRegion used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(AdministrationRegion.class);
  }

  /**
   * The result of the request. One of: success, noStreetSegmentFound, addressUnparseable,
   * noAddressParameter, multipleStreetSegmentsFound, electionOver, electionUnknown,
   * internalLookupFailure
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * Contests that will appear on the voter's ballot
   * The value returned may be {@code null}.
   */
  public java.util.List<Contest> getContests() {
    return contests;
  }

  /**
   * Contests that will appear on the voter's ballot
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setContests(java.util.List<Contest> contests) {
    this.contests = contests;
    return this;
  }

  /**
   * Locations where the voter is eligible to vote early, prior to election day
   * The value returned may be {@code null}.
   */
  public java.util.List<PollingLocation> getEarlyVoteSites() {
    return earlyVoteSites;
  }

  /**
   * Locations where the voter is eligible to vote early, prior to election day
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setEarlyVoteSites(java.util.List<PollingLocation> earlyVoteSites) {
    this.earlyVoteSites = earlyVoteSites;
    return this;
  }

  /**
   * The election that was queried.
   * The value returned may be {@code null}.
   */
  public Election getElection() {
    return election;
  }

  /**
   * The election that was queried.
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setElection(Election election) {
    this.election = election;
    return this;
  }

  /**
   * The kind, fixed to "civicinfo#voterInfoResponse".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "civicinfo#voterInfoResponse".
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The normalized version of the requested address
   * The value returned may be {@code null}.
   */
  public SimpleAddressType getNormalizedInput() {
    return normalizedInput;
  }

  /**
   * The normalized version of the requested address
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setNormalizedInput(SimpleAddressType normalizedInput) {
    this.normalizedInput = normalizedInput;
    return this;
  }

  /**
   * Locations where the voter is eligible to vote on election day. For states with mail-in voting
   * only, these locations will be nearby drop box locations. Drop box locations are free to the
   * voter and may be used instead of placing the ballot in the mail.
   * The value returned may be {@code null}.
   */
  public java.util.List<PollingLocation> getPollingLocations() {
    return pollingLocations;
  }

  /**
   * Locations where the voter is eligible to vote on election day. For states with mail-in voting
   * only, these locations will be nearby drop box locations. Drop box locations are free to the
   * voter and may be used instead of placing the ballot in the mail.
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setPollingLocations(java.util.List<PollingLocation> pollingLocations) {
    this.pollingLocations = pollingLocations;
    return this;
  }

  /**
   * Local Election Information for the state that the voter votes in. For the US, there will only
   * be one element in this array.
   * The value returned may be {@code null}.
   */
  public java.util.List<AdministrationRegion> getState() {
    return state;
  }

  /**
   * Local Election Information for the state that the voter votes in. For the US, there will only
   * be one element in this array.
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setState(java.util.List<AdministrationRegion> state) {
    this.state = state;
    return this;
  }

  /**
   * The result of the request. One of: success, noStreetSegmentFound, addressUnparseable,
   * noAddressParameter, multipleStreetSegmentsFound, electionOver, electionUnknown,
   * internalLookupFailure
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The result of the request. One of: success, noStreetSegmentFound, addressUnparseable,
   * noAddressParameter, multipleStreetSegmentsFound, electionOver, electionUnknown,
   * internalLookupFailure
   * The value set may be {@code null}.
   */
  public VoterInfoResponse setStatus(String status) {
    this.status = status;
    return this;
  }

}
